@@ -57,6 +57,7 @@ precision.data.frame <- function(data,
                                  estimate,
                                  estimator = NULL,
                                  na_rm = TRUE,
+                                 case_weights = NULL,
                                  event_level = yardstick_event_level(),
                                  ...) {
   metric_summarizer(
@@ -67,6 +68,7 @@ precision.data.frame <- function(data,
     estimate = !!enquo(estimate),
     estimator = estimator,
     na_rm = na_rm,
+    case_weights = !!enquo(case_weights),
     event_level = event_level
   )
 }
@@ -101,17 +103,15 @@ precision_vec <- function(truth,
                           estimate,
                           estimator = NULL,
                           na_rm = TRUE,
+                          case_weights = NULL,
                           event_level = yardstick_event_level(),
                           ...) {
   estimator <- finalize_estimator(truth, estimator)
 
-  precision_impl <- function(truth, estimate) {
-    xtab <- vec2table(
-      truth = truth,
-      estimate = estimate
-    )
-
-    precision_table_impl(xtab, estimator, event_level)
+  precision_impl <- function(truth, estimate, ..., case_weights = NULL) {
+    check_dots_empty()
+    data <- yardstick_table(truth, estimate, case_weights = case_weights)
+    precision_table_impl(data, estimator, event_level)
   }
 
   metric_vec_template(
@@ -120,6 +120,7 @@ precision_vec <- function(truth,
     estimate = estimate,
     na_rm = na_rm,
     estimator = estimator,
+    case_weights = case_weights,
     cls = "factor"
   )
 }
@@ -131,7 +132,7 @@ precision_table_impl <- function(data, estimator, event_level) {
     w <- get_weights(data, estimator)
     out_vec <- precision_multiclass(data, estimator)
     # set `na.rm = TRUE` to remove undefined values from weighted computation (#98)
-    weighted.mean(out_vec, w, na.rm = TRUE)
+    stats::weighted.mean(out_vec, w, na.rm = TRUE)
   }
 }
 
