@@ -1,12 +1,10 @@
-# ------------------------------------------------------------------------------
-
 test_that("two class produces identical results regardless of level order", {
   lst <- data_altman()
   df <- lst$pathology
 
   df_rev <- df
-  df_rev$pathology <- relevel(df_rev$pathology, "norm")
-  df_rev$scan <- relevel(df_rev$scan, "norm")
+  df_rev$pathology <- stats::relevel(df_rev$pathology, "norm")
+  df_rev$scan <- stats::relevel(df_rev$scan, "norm")
 
   expect_equal(
     accuracy_vec(df$pathology, df$scan),
@@ -14,8 +12,6 @@ test_that("two class produces identical results regardless of level order", {
   )
 })
 
-# ------------------------------------------------------------------------------
-
 test_that('Three class', {
   lst <- data_three_class()
   three_class <- lst$three_class
@@ -47,7 +43,20 @@ test_that('Three class', {
   )
 })
 
-# sklearn compare --------------------------------------------------------------
+test_that("two class with case weights is correct", {
+  df <- data.frame(
+    truth = factor(c("x", "x", "y"), levels = c("x", "y")),
+    estimate = factor(c("x", "y", "x"), levels = c("x", "y")),
+    case_weights = c(1L, 1L, 2L)
+  )
+
+  # 1 correct, 2 wrong. Normally 1/3 accuracy, but one of the wrong
+  # values is weighted 2x so we get 1/4.
+  expect_identical(
+    accuracy(df, truth, estimate, case_weights = case_weights)[[".estimate"]],
+    1/4
+  )
+})
 
 test_that('Two class - sklearn equivalent', {
   py_res <- read_pydata("py-accuracy")
